NAME
Sisimai::Reason::SpamDetected - Bounce reason is rejected due to Spam content in the message or not.
SYNOPSIS
use Sisimai::Reason::SpamDetected;
print Sisimai::Reason::SpamDetected->match('550 spam detected'); # 1
DESCRIPTION
Sisimai::Reason::SpamDetected checks the bounce reason is rejected due to Spam content in the message or not. This class is called only Sisimai::Reason class.
CLASS METHODS
text()
text() returns string: spamdetected.
print Sisimai::Reason::SpamDetected->text; # spamdetected
match( string )
match() returns 1 if the argument matched with patterns defined in this class.
print Sisimai::Reason::SpamDetected->match('550 Spam detected'); # 1
true( Sisimai::Data )
true() returns 1 if the bounce reason is rejected due to Spam content in the message. The argument must be Sisimai::Data object and this method is called only from Sisimai::Reason class.
AUTHOR
azumakuniyuki
COPYRIGHT
Copyright (C) 2015 azumakuniyuki <perl.org@azumakuniyuki.org>, All Rights Reserved.
LICENSE
This software is distributed under The BSD 2-Clause License.